@@ -14,9 +14,16 @@
 #  You should have received a copy of the GNU Lesser General Public
 #  License along with this library.
 
+from octobot_tentacles_manager.models import artifact
+from octobot_tentacles_manager.models.artifact import (
+    Artifact,
+)
+
 from octobot_tentacles_manager.models import tentacle_type
 from octobot_tentacles_manager.models import tentacle_factory
 from octobot_tentacles_manager.models import tentacle
+from octobot_tentacles_manager.models import tentacle_package
+from octobot_tentacles_manager.models import tentacle_bundle
 
 from octobot_tentacles_manager.models.tentacle_type import (
     TentacleType,
@@ -27,9 +34,18 @@ from octobot_tentacles_manager.models.tentacle_factory import (
 from octobot_tentacles_manager.models.tentacle import (
     Tentacle,
 )
+from octobot_tentacles_manager.models.tentacle_package import (
+    TentaclePackage,
+)
+from octobot_tentacles_manager.models.tentacle_bundle import (
+    TentacleBundle,
+)
 
 __all__ = [
+    "Artifact",
     "TentacleType",
     "TentacleFactory",
     "Tentacle",
+    "TentaclePackage",
+    "TentacleBundle"
 ]
