@@ -13,8 +13,7 @@
 #
 #  You should have received a copy of the GNU Lesser General Public
 #  License along with this library.
-from octobot_tentacles_manager.models.tentacle import Tentacle
-from octobot_tentacles_manager.models.tentacle_type import TentacleType
+import octobot_tentacles_manager.models as models
 
 
 class TentacleFactory:
@@ -22,10 +21,10 @@ class TentacleFactory:
         self.tentacle_root_path = tentacle_root_path
 
     def create_tentacle_from_type(self, name, tentacle_type):
-        return Tentacle(self.tentacle_root_path, name, tentacle_type)
+        return models.Tentacle(self.tentacle_root_path, name, tentacle_type)
 
     async def create_and_load_tentacle_from_module(self, tentacle_module):
-        tentacle_type = TentacleType.from_import_path(self.tentacle_root_path, tentacle_module.__name__)
-        tentacle = Tentacle(self.tentacle_root_path, tentacle_type.module_name, tentacle_type)
+        tentacle_type = models.TentacleType.from_import_path(self.tentacle_root_path, tentacle_module.__name__)
+        tentacle = models.Tentacle(self.tentacle_root_path, tentacle_type.module_name, tentacle_type)
         await tentacle.initialize()
         return tentacle
